@@ -44,6 +44,7 @@ import io.netty.channel.epoll.EpollServerSocketChannel;
 import io.netty.channel.group.ChannelGroup;
 import io.netty.channel.group.ChannelGroupFuture;
 import io.netty.channel.group.DefaultChannelGroup;
+import io.netty.channel.local.LocalAddress;
 import io.netty.channel.local.LocalChannel;
 import io.netty.channel.local.LocalServerChannel;
 import io.netty.channel.socket.SocketChannel;
@@ -77,6 +78,7 @@ import org.apache.bookkeeper.bookie.BookieException;
 import org.apache.bookkeeper.common.collections.BlockingMpscQueue;
 import org.apache.bookkeeper.common.util.affinity.CpuAffinity;
 import org.apache.bookkeeper.conf.ServerConfiguration;
+import org.apache.bookkeeper.net.BookieId;
 import org.apache.bookkeeper.net.BookieSocketAddress;
 import org.apache.bookkeeper.processor.RequestProcessor;
 import org.apache.bookkeeper.util.ByteBufList;
@@ -103,6 +105,7 @@ class BookieNettyServer {
     volatile boolean suspended = false;
     ChannelGroup allChannels;
     final BookieSocketAddress bookieAddress;
+    final BookieId bookieId;
     final InetSocketAddress bindAddress;
 
     final BookieAuthProvider.Factory authProviderFactory;
@@ -160,7 +163,7 @@ class BookieNettyServer {
         } else {
             jvmEventLoopGroup = null;
         }
-
+        bookieId = Bookie.getBookieId(conf);
         bookieAddress = Bookie.getBookieAddress(conf);
         if (conf.getListeningInterface() == null) {
             bindAddress = new InetSocketAddress(conf.getBookiePort());
@@ -186,7 +189,7 @@ class BookieNettyServer {
             for (Channel channel : allChannels) {
                 // To suspend processing in the bookie, submit a task
                 // that keeps the event loop busy until resume is
-                // explicitely invoked
+                // explicitly invoked
                 channel.eventLoop().submit(() -> {
                     while (suspended && isRunning()) {
                         try {
@@ -351,6 +354,7 @@ class BookieNettyServer {
             });
 
             // Bind and start to accept incoming connections
+            LOG.info("Binding bookie-rpc endpoint to {}", address);
             Channel listen = bootstrap.bind(address.getAddress(), address.getPort()).sync().channel();
             if (listen.localAddress() instanceof InetSocketAddress) {
                 if (conf.getBookiePort() == 0) {
@@ -409,10 +413,10 @@ class BookieNettyServer {
                     pipeline.addLast("contextHandler", contextHandler);
                 }
             });
-
+            LOG.info("Binding jvm bookie-rpc endpoint to {}", bookieId.toString());
             // use the same address 'name', so clients can find local Bookie still discovering them using ZK
-            jvmBootstrap.bind(bookieAddress.getLocalAddress()).sync();
-            LocalBookiesRegistry.registerLocalBookieAddress(bookieAddress);
+            jvmBootstrap.bind(new LocalAddress(bookieId.toString())).sync();
+            LocalBookiesRegistry.registerLocalBookieAddress(bookieId);
         }
     }
 
@@ -440,7 +444,7 @@ class BookieNettyServer {
             }
         }
         if (jvmEventLoopGroup != null) {
-            LocalBookiesRegistry.unregisterLocalBookieAddress(bookieAddress);
+            LocalBookiesRegistry.unregisterLocalBookieAddress(bookieAddress.toBookieId());
             jvmEventLoopGroup.shutdownGracefully();
         }
 
