@@ -56,6 +56,7 @@ import org.apache.bookkeeper.client.api.LedgerMetadata;
 import org.apache.bookkeeper.common.testing.executors.MockExecutorController;
 import org.apache.bookkeeper.conf.ClientConfiguration;
 import org.apache.bookkeeper.meta.zk.ZKMetadataDriverBase;
+import org.apache.bookkeeper.net.BookieId;
 import org.apache.bookkeeper.net.BookieSocketAddress;
 import org.apache.bookkeeper.proto.BookkeeperInternalCallbacks.LedgerMetadataListener;
 import org.apache.bookkeeper.util.ZkUtils;
@@ -115,13 +116,13 @@ public class AbstractZkLedgerManagerTest extends MockZooKeeperTestCase {
             withSettings()
                 .useConstructor(conf, mockZk)
                 .defaultAnswer(CALLS_REAL_METHODS));
-        List<BookieSocketAddress> ensemble = Lists.newArrayList(
-                new BookieSocketAddress("192.0.2.1", 3181),
-                new BookieSocketAddress("192.0.2.2", 3181),
-                new BookieSocketAddress("192.0.2.3", 3181),
-                new BookieSocketAddress("192.0.2.4", 3181),
-                new BookieSocketAddress("192.0.2.5", 3181));
+        List<BookieId> ensemble = Lists.newArrayList(new BookieSocketAddress("192.0.2.1", 3181).toBookieId(),
+                new BookieSocketAddress("192.0.2.2", 3181).toBookieId(),
+                new BookieSocketAddress("192.0.2.3", 3181).toBookieId(),
+                new BookieSocketAddress("192.0.2.4", 3181).toBookieId(),
+                new BookieSocketAddress("192.0.2.5", 3181).toBookieId());
         this.metadata = LedgerMetadataBuilder.create()
+            .withId(123L)
             .withDigestType(DigestType.CRC32C).withPassword(new byte[0])
             .withEnsembleSize(5)
             .withWriteQuorumSize(3)
